# AirForm

Pydantic-native form validation and rendering. Define a model, get a validated, rendered HTML form. Works with or without Air web framework.

## Getting started

- [Installation](installation.md) - how to install AirForm
- [Usage](usage.md) - how to use AirForm
- [API Reference](api.md) - auto-generated API documentation
